html, button, input, select, textarea {
  color: #222; }

html {
  /* margin: 0; */ }

body {
  font: 13px/1.5 "Helvetica Neue", Arial, "Liberation Sans", FreeSans, sans-serif;
  overflow: hidden; }

hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid #ccc;
  margin: 1em 0;
  padding: 0; }

img {
  vertical-align: middle; }

fieldset {
  border: 0;
  margin: 0;
  padding: 0; }

textarea {
  resize: vertical; }

.chromeframe {
  margin: 0.2em 0;
  background: #ccc;
  color: #000;
  padding: 0.2em 0; }

.unselectable {
  -moz-user-select: -moz-none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -o-user-select: none;
  user-select: none; }

.ir {
  background-color: transparent;
  border: 0;
  overflow: hidden;
  text-indent: -9999px; }

.ir:before {
  content: "";
  display: block;
  width: 0;
  height: 150%; }

.hidden {
  display: none !important;
  visibility: hidden; }

.visuallyhidden {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px; }

.visuallyhidden.focusable:active,
.visuallyhidden.focusable:focus {
  clip: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  position: static;
  width: auto; }

.invisible {
  visibility: hidden; }

.clearfix:before,
.clearfix:after {
  content: " ";
  display: table; }

.clearfix:after {
  clear: both; }

.clearfix {
  zoom: 1; }

body {
  background-color: #1d1f21; }

/* toolbar styles */
.toolbar {
  width: 100%;
  background: #282a2e;
  padding: 5px;
  -webkit-box-direction: normal;
  -moz-box-direction: normal;
  -webkit-box-orient: horizontal;
  -moz-box-orient: horizontal;
  display: -webkit-box;
  display: -moz-box;
  display: -ms-flexbox;
  display: -webkit-flex;
  display: flex;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  -webkit-box-pack: start;
  -moz-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-content: stretch;
  -ms-flex-line-pack: stretch;
  align-content: stretch;
  -webkit-box-align: center;
  -moz-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center; }

.toolbar-item {
  height: 100%;
  padding-right: 5px;
  -webkit-box-ordinal-group: 1;
  -moz-box-ordinal-group: 1;
  -webkit-order: 0;
  -ms-flex-order: 0;
  order: 0;
  -moz-box-flex: 0;
  -webkit-flex: 0 0 auto;
  -ms-flex: 0 0 auto;
  flex: 0 0 auto;
  -webkit-align-self: flex-start;
  -ms-flex-item-align: flex-start;
  align-self: flex-start; }

.toolbar-item-fill {
  -moz-box-flex: 1;
  -webkit-flex: 1 0 auto;
  -ms-flex: 1 0 auto;
  flex: 1 0 auto; }

#logselect {
  min-width: 300px; }

#modeselect {
  min-width: 80px; }

#scriptinput {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  -o-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-box-shadow: #202225 2px 2px 2px 0px;
  -moz-box-shadow: #202225 2px 2px 2px 0px;
  box-shadow: #202225 2px 2px 2px 0px;
  height: 26px;
  background: #373b41;
  padding-right: 30px;
  position: relative; }
  #scriptinput input {
    padding-left: 0.5em;
    height: 100%;
    width: 100%;
    text-align: center; }
  #scriptinput div {
    line-height: 26px;
    color: #888;
    text-align: center;
    vertical-align: middle;
    cursor: pointer;
    cursor: hand;
    display: block;
    position: absolute;
    right: 0;
    top: 0;
    width: 22px; }

.toolbar-widget, #scriptinput input, .button-group a, .select-container .select2-choice {
  color: #c5c8c6;
  background: #373b41;
  border: 0;
  border-radius: 0;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  -o-box-sizing: border-box;
  box-sizing: border-box; }

.toolbar-hover, #scriptinput div:hover, .button-group a:hover, .select-container .select2-choice div b:hover, .select-container .select2-choice div b.hovered {
  background-color: #43484f; }

.toolbar-text, #scriptinput input, .select-container {
  font-family: Bitstream Vera Sans Mono, Consolas, Monaco, Lucida Console, Liberation Mono, DejaVu Sans Mono, Courier New, monospace;
  font-size: 11px; }

.button-group {
  height: 26px; }
  .button-group a {
    -webkit-box-shadow: #202225 2px 2px 2px 0px;
    -moz-box-shadow: #202225 2px 2px 2px 0px;
    box-shadow: #202225 2px 2px 2px 0px;
    float: left;
    margin-right: 0;
    height: 26px;
    width: 26px;
    text-align: center;
    line-height: 26px;
    font-size: 1.5em; }
    .button-group a:link, .button-group a:visited, .button-group a:active {
      text-decoration: none;
      outline: none; }

.quickbar {
  position: absolute;
  top: 5px;
  right: 5px; }

.select-dropdown-container {
  border: 0;
  border-radius: 0;
  font-family: Bitstream Vera Sans Mono, Consolas, Monaco, Lucida Console, Liberation Mono, DejaVu Sans Mono, Courier New, monospace;
  font-size: smaller;
  color: #c5c8c6;
  background: #373b41; }

.select-container {
  -webkit-box-shadow: #202225 2px 2px 2px 0px;
  -moz-box-shadow: #202225 2px 2px 2px 0px;
  box-shadow: #202225 2px 2px 2px 0px;
  border: 0;
  vertical-align: middle;
  width: 20%; }
  .select-container .select2-default {
    color: #c5c8c6;
    font-style: italic;
    text-align: center; }
  .select-container .select2-choice {
    height: 100%;
    padding-left: 0; }
    .select-container .select2-choice span {
      width: 100%;
      padding-left: 8px;
      background: #373b41; }
  .select-container .select2-choice div {
    border: 0; }
  .select-container .select2-choice div b {
    background: url("../js/vendor/select2.png") no-repeat scroll 0 1px #373b41;
    border: 0;
    display: block;
    height: 100%;
    width: 100%; }

/* log view style */
.scrollable {
  overflow-y: auto; }

.log-view {
  white-space: nowrap;
  font-family: Bitstream Vera Sans Mono, Consolas, Monaco, Lucida Console, Liberation Mono, DejaVu Sans Mono, Courier New, monospace;
  font-size: 10px;
  overflow-y: auto;
  line-height: 1.3;
  color: #c5c8c6;
  background-color: #1d1f21; }
  .log-view .log-entry {
    display: block; }
  .log-view .log-entry-current {
    background: #282a2e; }
  .log-view .log-notice {
    background: #c66;
    color: #1d1f21;
    text-align: center;
    font-weight: bold; }

.log-view ::-moz-selection {
  background: #373b41;
  text-shadow: none; }

.log-view ::selection {
  background: #373b41;
  text-shadow: none; }

input::-moz-selection {
  background: black;
  text-shadow: none;
  color: white; }

input::selection {
  background: black;
  text-shadow: none;
  color: white; }

input::-webkit-input-placeholder {
  color: #c5c8c6;
  font-style: italic;
  text-align: center; }

input:-moz-placeholder {
  color: #c5c8c6;
  font-style: italic;
  text-align: center; }

input::-moz-placeholder {
  color: #c5c8c6;
  font-style: italic;
  text-align: center; }

input:-ms-input-placeholder {
  color: #c5c8c6;
  font-style: italic;
  text-align: center; }
